query

Function query 

pub fn query(command: &str, word: &str) -> Vec<String>
Run mutt’s query_command (%s = the search word, appended when the command has no %s) and parse its output: the first line is a human message, then one address<TAB>name[<TAB>extra] per line.