pub fn attach_line(a: &Attachment) -> StringExpand description
One Attach: line back from its parts (quotes around a path with spaces, then the optional type and description).
pub fn attach_line(a: &Attachment) -> StringOne Attach: line back from its parts (quotes around a path with spaces, then the optional type and description).