render_status

Function render_status 

pub fn render_status(
    fmt: &str,
    width: usize,
    value_of: &dyn Fn(char) -> String,
) -> String
render_with plus mutt’s %>X: everything after it is pushed to the right edge of width, the gap filled with X (the status line uses this; only the first %> counts).